@@ -11,6 +11,7 @@
 import random
 import string
 import hashlib
+import urllib
 
 from wtforms import Form, TextField, IntegerField, SelectField, validators, \
     PasswordField
@@ -591,6 +592,39 @@ class NereidUser(ModelSQL, ModelView):
         """
         return super(NereidUser, self).write(ids, self._convert_values(values))
 
+    def get_profile_picture(self, user, **kwargs):
+        """
+        By default tries to get the email of the user and construct a gravatar 
+        URL from it
+
+        To change the behavior inherit `nereid.user` and change this method to
+        return an URL
+
+        :param user: Browse Record of the user
+
+        Other keyword arguments
+
+        :param https: To get a secure URL
+        :param default: The default image to return if there is no profile pic
+                        For example a unisex avatar
+        :param size: The size for the image
+        """
+        if kwargs.get('https', request.scheme == 'https'):
+            url = 'https://secure.gravatar.com/avatar/%s?'
+        else:
+            url = 'http://www.gravatar.com/avatar/%s?'
+        url = url % hashlib.md5(user.email.lower()).hexdigest()
+
+        params = []
+        default = kwargs.get('default', None)
+        if default:
+            params.append(('d', default))
+
+        size = kwargs.get('size', None)
+        if size:
+            params.append(('s', str(size)))
+
+        return url + urllib.urlencode(params)
 
 NereidUser()
 
